@@ -2,7 +2,7 @@ package Google::API::Client;
 
 use strict;
 use 5.008_001;
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 use Google::API::Method;
 use Google::API::Resource;
@@ -154,6 +154,12 @@ Hatsuhito UENO (uehatsu)
 
 chylli
 
+Richie Foreman <richieforeman@google.com> (richieforeman)
+
+ljanvier
+
+razsh
+
 =head1 COPYRIGHT
 
 Copyright 2011- Takatsugu Shigeta
